<?php
/**
 * Fake database row to represent a user in privacy mode.
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2015.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @category VuFind2
 * @package  Db_Row
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org   Main Site
 */
namespace VuFind\Db\Row;

/**
 * Fake database row to represent a user in privacy mode.
 *
 * @category VuFind2
 * @package  Db_Row
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org   Main Site
 */
class PrivateUser extends User
{
    /**
     * __get
     *
     * @param string $name Field to retrieve.
     *
     * @throws Exception\InvalidArgumentException
     * @return mixed
     */
    public function __get($name)
    {
        return array_key_exists($name, $this->data) ? parent::__get($name) : null;
    }

    /**
     * Whether library cards are enabled
     *
     * @return bool
     */
    public function libraryCardsEnabled()
    {
        return false; // not supported in this context
    }

    /**
     * Save
     *
     * @return int
     */
    public function save()
    {
        $this->initialize();
        $this->id = -1; // fake ID
        $session = new \Zend\Session\Container('Account');
        $session->userDetails = $this->toArray();
        return 1;
    }
}
